aboutsummaryrefslogtreecommitdiffstats
path: root/googlemock/scripts
diff options
context:
space:
mode:
authorSimon Newton <nomis52@gmail.com>2015-09-17 08:33:43 -0700
committerSimon Newton <nomis52@gmail.com>2015-09-17 08:33:43 -0700
commit39062f4e3005cac0b919d3dbe83b3d1e6b61a8ae (patch)
tree9f346d9bfb4c5769d59159ef812c7c00edeecd33 /googlemock/scripts
parentde411c3e80120f8dcc2a3f4f62f3ca692c0431d7 (diff)
downloadgoogletest-39062f4e3005cac0b919d3dbe83b3d1e6b61a8ae.tar.gz
googletest-39062f4e3005cac0b919d3dbe83b3d1e6b61a8ae.tar.bz2
googletest-39062f4e3005cac0b919d3dbe83b3d1e6b61a8ae.zip
Fix the googlemock autotools build.
Diffstat (limited to 'googlemock/scripts')
-rwxr-xr-xgooglemock/scripts/fuse_gmock_files.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/googlemock/scripts/fuse_gmock_files.py b/googlemock/scripts/fuse_gmock_files.py
index fc0baf79..cb7fdf2f 100755
--- a/googlemock/scripts/fuse_gmock_files.py
+++ b/googlemock/scripts/fuse_gmock_files.py
@@ -36,8 +36,8 @@ SYNOPSIS
fuse_gmock_files.py [GMOCK_ROOT_DIR] OUTPUT_DIR
Scans GMOCK_ROOT_DIR for Google Mock and Google Test source
- code, assuming Google Test is in the GMOCK_ROOT_DIR/gtest
- sub-directory, and generates three files:
+ code, assuming Google Test is in the GMOCK_ROOT_DIR/../googletest
+ directory, and generates three files:
OUTPUT_DIR/gtest/gtest.h, OUTPUT_DIR/gmock/gmock.h, and
OUTPUT_DIR/gmock-gtest-all.cc. Then you can build your tests
by adding OUTPUT_DIR to the include search path and linking
@@ -70,8 +70,8 @@ import sys
# Mock root directory.
DEFAULT_GMOCK_ROOT_DIR = os.path.join(os.path.dirname(__file__), '..')
-# We need to call into gtest/scripts/fuse_gtest_files.py.
-sys.path.append(os.path.join(DEFAULT_GMOCK_ROOT_DIR, 'gtest/scripts'))
+# We need to call into googletest/scripts/fuse_gtest_files.py.
+sys.path.append(os.path.join(DEFAULT_GMOCK_ROOT_DIR, '../googletest/scripts'))
import fuse_gtest_files
gtest = fuse_gtest_files
@@ -91,7 +91,7 @@ GMOCK_GTEST_ALL_CC_OUTPUT = 'gmock-gtest-all.cc'
def GetGTestRootDir(gmock_root):
"""Returns the root directory of Google Test."""
- return os.path.join(gmock_root, 'gtest')
+ return os.path.join(gmock_root, '../googletest')
def ValidateGMockRootDir(gmock_root):